@@ -1,3 +1,4 @@
+# coding=utf-8
 import diagram
 import io
 
@@ -7,6 +8,8 @@ class Line:
         """
         折线图
 
+        line chart
+
         :param values: 值列表
         :param height: 高度
         :param width: 宽度
@@ -19,6 +22,8 @@ class Line:
         """
         绘图并返回字符串
 
+        Draw and return a string
+
         :return: 折线图的字符串
         """
         opt = diagram.DOption()
@@ -37,6 +42,8 @@ class Line:
         """
         尾部添加值
 
+        Tail add value
+
         :param x: 值
         :return: None
         """
@@ -46,6 +53,8 @@ class Line:
         """
         删除首部值
 
+        Delete bow value
+
         :return: None
         """
         self.values.pop(0)
